@@ -22,13 +22,9 @@
 #ifndef NOTES_HEADER
 #define NOTES_HEADER
 
-#include <QGraphicsLinearLayout>
 #include <QTimer>
 
-#include <KTextEdit>
-#include <KRichTextEdit>
-
-#include <Plasma/Applet>
+#include <Plasma/PopupApplet>
 #include <Plasma/Svg>
 #include <Plasma/TextEdit>
 #include <Plasma/ToolButton>
@@ -38,83 +34,12 @@
 class QGraphicsLinearLayout;
 class QSizeF;
 class QContextMenuEvent;
-class QGraphicsWidget;
 class QParallelAnimationGroup;
 
-namespace Plasma
-{
-    class TextEdit;
-    class Animation;
-}
+class TopWidget;
+class NotesTextEdit;
 
-/**
- * @short Notes Version von KTextEdit
- *
- * This is just a little subclass of KTextEdit which provides a customized context menu and the ability to save its content into a file
- *
- * @see QTextEdit
- * @author Björn Ruberg <bjoern@ruberg-wegener.de>
- */
-class NotesTextEdit : public KRichTextEdit {
-    Q_OBJECT
-
-    public:
-        NotesTextEdit(QWidget *parent = 0);
-        ~NotesTextEdit();
-
-        void setFormatMenu(QMenu *menu);
-
-    public slots:
-        virtual void saveToFile();
-        void italic();
-        void bold();
-        void underline();
-        void strikeOut();
-        void justifyCenter();
-        void justifyFill();
-
-    Q_SIGNALS:
-        void cursorMoved();
-        void mouseUnhovered();
-        void scrolledUp();
-        void scrolledDown();
-
-    protected:
-        virtual void contextMenuEvent ( QContextMenuEvent *e )  ;
-        void mousePressEvent ( QMouseEvent * event );
-        void keyPressEvent ( QKeyEvent * event );
-        void leaveEvent ( QEvent * event );
-        void wheelEvent ( QWheelEvent * event );
-
-    private:
-        QMenu *m_formatMenu;
-};
-
-/**
- * @short Notes Version von KTextEdit
- *
- * This is a Plasma::TextEdit which uses NotesTextEdit as native widget
- *
- * @see QTextEdit
- * @author Björn Ruberg <bjoern@ruberg-wegener.de>
- */
-class PlasmaTextEdit : public Plasma::TextEdit {
-    Q_OBJECT
-
-    signals:
-    void mouseUnhovered();
-
-    public:
-      PlasmaTextEdit(QGraphicsWidget *parent = 0);
-      ~PlasmaTextEdit();
-      NotesTextEdit* native;
-
-    protected:
-      void mousePressEvent(QGraphicsSceneMouseEvent *event);
-      void focusOutEvent(QFocusEvent *event);
-};
-
-class Notes : public Plasma::Applet
+class Notes : public Plasma::PopupApplet
 {
     Q_OBJECT
 
@@ -123,28 +48,27 @@ class Notes : public Plasma::Applet
         ~Notes();
         void init();
         QList<QAction*> contextualActions();
-        void paintInterface(QPainter *painter,
-                            const QStyleOptionGraphicsItem *option,
-                            const QRect& contentsRect);
 
     public Q_SLOTS:
+        void configChanged();
         void configAccepted();
         void showOptions(bool show);
 
     protected:
         void constraintsEvent(Plasma::Constraints constraints);
         void createConfigurationInterface(KConfigDialog *parent);
+        void saveState(KConfigGroup &cg) const;
 
     private Q_SLOTS:
         void saveNote();
         void delayedSaveNote();
         void changeColor(QAction*);
         void lineChanged();
-        void mouseUnhovered();
         void increaseFontSize();
         void decreaseFontSize();
         void themeChanged();
         void updateOptions();
+        void showError(const QString &message);
 
     private:
         void createTextFormatingWidgets();
@@ -164,14 +88,13 @@ class Notes : public Plasma::Applet
         int m_wheelFontAdjustment;
         QColor m_textColor;
         QColor m_textBackgroundColor;
-        QString m_color;
 
         QMenu *m_colorMenu;
         QMenu *m_formatMenu;
 
-        Plasma::Svg m_notesTheme;
         QGraphicsLinearLayout *m_layout;
-        PlasmaTextEdit *m_textEdit;
+        Plasma::TextEdit *m_textEdit;
+        NotesTextEdit *m_noteEditor;
         Ui::config ui;
 
         QSizeF m_size;
@@ -183,11 +106,10 @@ class Notes : public Plasma::Applet
         Plasma::ToolButton *m_buttonStrikeThrough;
         Plasma::ToolButton *m_buttonCenter;
         Plasma::ToolButton *m_buttonFill;
+        TopWidget *m_topWidget;
 
         QParallelAnimationGroup *m_buttonAnimGroup;
         Plasma::Animation *m_buttonAnim[6];
 };
 
-K_EXPORT_PLASMA_APPLET(notes, Notes)
-
 #endif
