@@ -23,12 +23,14 @@
 #include <KLocale>
 #include <KIcon>
 #include <KToolInvocation>
+#include <akonadi/contact/contactdefaultactions.h>
 /*#include <KMimeType>
 
 */
 
 #include <kabc/stdaddressbook.h>
 #include <kabc/addressee.h>
+#include <kabc/phonenumber.h>
 #include <kabc/picture.h>
 
 #include "imageiconengine.h"
@@ -37,13 +39,13 @@ ContactsRunner::ContactsRunner(QObject *parent, const QVariantList& args)
     : Plasma::AbstractRunner(parent, args)
 {
     Q_UNUSED(args);
-    setObjectName("Contacts");
+    setObjectName(QLatin1String( "Contacts" ));
 
     m_book = KABC::StdAddressBook::self(true /*asynchronous*/);
 
-    m_icon = KIcon("internet-mail");
+    m_icon = KIcon(QLatin1String( "internet-mail" ));
     setIgnoredTypes(Plasma::RunnerContext::FileSystem | Plasma::RunnerContext::NetworkLocation);
-    addSyntax(Plasma::RunnerSyntax(":q:", i18n("Finds people in your address book matching :q:.")));
+    addSyntax(Plasma::RunnerSyntax(QLatin1String( ":q:" ), i18n("Finds people in your address book matching :q:.")));
     setDefaultSyntax(Plasma::RunnerSyntax(i18nc("list of all people in address book", "contacts"),
                                    i18n("List all people in your address book.")));
 }
@@ -70,7 +72,7 @@ void ContactsRunner::match(Plasma::RunnerContext &context)
         bool matchedName;
         bool matchedMail;
 
-        if (term.compare(i18nc("list of all people in address book", "contacts"), Qt::CaseInsensitive) == 0 || term.compare("contacts", Qt::CaseInsensitive) == 0) {
+        if (term.compare(i18nc("list of all people in address book", "contacts"), Qt::CaseInsensitive) == 0 || term.compare(QLatin1String( "contacts" ), Qt::CaseInsensitive) == 0) {
             matchedName = true;
             matchedMail = true;
         } else {
@@ -81,7 +83,7 @@ void ContactsRunner::match(Plasma::RunnerContext &context)
         if (!matchedName && !matchedMail) {
             // Name didn't match, so lets try the name portion of the email address
             const int indexOf = a.preferredEmail().indexOf(term, Qt::CaseInsensitive);
-            matchedMail = indexOf > -1 && indexOf < a.preferredEmail().indexOf('@');
+            matchedMail = indexOf > -1 && indexOf < a.preferredEmail().indexOf(QLatin1Char( '@' ));
         }
 
         if ((matchedName || matchedMail) && !a.preferredEmail().isEmpty()) {
@@ -111,12 +113,54 @@ void ContactsRunner::match(Plasma::RunnerContext &context)
             match.setText(i18nc("Open the default mail program to mail someone", "Mail to %1", a.realName()));
 
             if (!a.realName().isEmpty()) {
-                match.setData(a.realName() + '<' + a.preferredEmail() + '>');
+                match.setData(QString(a.realName() + QLatin1String( " <" ) + a.preferredEmail() + QLatin1Char( '>' )));
             } else {
                 match.setData(a.preferredEmail());
             }
             matches.append(match);
         }
+
+        if (matchedName) {
+            KABC::PhoneNumber::TypeList list;
+            list << KABC::PhoneNumber::Home
+                 << KABC::PhoneNumber::Work
+                 << KABC::PhoneNumber::Voice
+                 << KABC::PhoneNumber::Cell
+                 << KABC::PhoneNumber::Video
+                 << KABC::PhoneNumber::Car;
+            foreach (const KABC::PhoneNumber::Type type, list) {
+                KABC::PhoneNumber phonenumber = a.phoneNumber(type);
+                if (!phonenumber.isEmpty()) {
+                    //kDebug() << "Possible match: " << a.realName() << " tel: " << phonenumber.number();
+                    Plasma::QueryMatch match(this);
+
+                    //TODO: exact match if the name is exact? =)
+                    match.setType(Plasma::QueryMatch::PossibleMatch);
+
+                    if (!a.photo().isEmpty()) {
+                        /* TODO it isn't anymore possible to use url as a photo for an user?
+                           if(a.photo().isIntern()) {
+                           }
+                           else {
+                           KURL url(a.photo().url());
+                           kDebug() << "photo url: " << url.prettyUrl() << endl;
+                           if(url.isLocalFile()) {
+                           icon = QIcon(url);
+                           }
+                           }*/
+                        QIcon icon(new ImageIconEngine(a.photo().data()));
+                        match.setIcon(icon);
+                    } else {
+                        match.setIcon(m_icon);
+                    }
+
+                    match.setText(i18nc("Open the default telephone program to call someone", "Call %1 at %2", a.realName(), phonenumber.typeLabel()));
+                    match.setSubtext(phonenumber.number());
+                    match.setData(QString(QLatin1String("call:") + phonenumber.number()));
+                    matches.append(match);
+                }
+            }
+	}
     }
 
     context.addMatches(term, matches);
@@ -130,7 +174,14 @@ void ContactsRunner::run(const Plasma::RunnerContext &context, const Plasma::Que
 
     kDebug() << "run name '" << name << "' with address '" << address << "'";
 
-    KToolInvocation::invokeMailer(address);
+    if (address.startsWith(QLatin1String("call:"))) {
+	KABC::PhoneNumber number;
+	number.setNumber(address.mid(5));
+	Akonadi::ContactDefaultActions actions;
+	actions.dialPhoneNumber( number );
+    } else {
+	KToolInvocation::invokeMailer(address);
+    }
 }
 
 #include "contactsrunner.moc"
